Skip to contents

Clinical description specification

Usage

clinicalDescriptionSpecification(path = NULL)

Arguments

path

If NULL, specification will be returned as an R object. If a path to a directory is provided the specification will be exported.

Value

JSON specification for clinical descriptions