Skip to contents

Data source description specification

Usage

dataSourceDescriptionSpecification(path = NULL)

Arguments

path

If NULL, specification will be returned as an R object. If a path to a directory is provided the specification will be exported.

Value

JSON specification for data source descriptions