Skip to contents

Shiny app to create data source descriptions for contextualising diagnostic results

Usage

shinyDataSourceDescriptions(directory, open = rlang::is_interactive())

Arguments

directory

Directory where to save shiny app

open

If TRUE, the shiny app will be launched in a new session. If FALSE, the shiny app will be created but not launched.

Value

Shiny app

Examples

# \donttest{
shinyDataSourceDescriptions(tempdir())
#>  Creating shiny from provided data
#>  Shiny app created in /tmp/Rtmpxdt0pr/dataSourceDescritpionShiny
# }