cohortDiagnostics: Run cohort-level diagnostics

View source: R/cohortDiagnostics.R

cohortDiagnosticsR Documentation

Run cohort-level diagnostics

Description

Runs phenotypeR diagnostics on the cohort. The diganostics include: * Age groups and sex summarised. * A summary of visits of everyone in the cohort using visit_occurrence table. * A summary of age and sex density of the cohort. * Attritions of the cohorts. * Overlap between cohorts (if more than one cohort is being used).

Usage

cohortDiagnostics(
  cohort,
  survival = FALSE,
  cohortSample = 20000,
  matchedSample = 1000
)

Arguments

cohort

Cohort table in a cdm reference

survival

Boolean variable. Whether to conduct survival analysis (TRUE) or not (FALSE).

cohortSample

The number of people to take a random sample for cohortDiagnostics. If 'cohortSample = NULL', no sampling will be performed.

matchedSample

The number of people to take a random sample for matching. If 'matchedSample = NULL', no sampling will be performed. If 'matchedSample = 0', no matched cohorts will be created.

Value

A summarised result

Examples


library(omock)
library(CohortConstructor)
library(PhenotypeR)

cdm <- mockCdmFromDataset(source = "duckdb")
cdm$warfarin <- conceptCohort(cdm,
                              conceptSet =  list(warfarin = c(1310149L,
                                                              40163554L)),
                              name = "warfarin")

result <- cohortDiagnostics(cdm$warfarin)


PhenotypeR documentation built on Feb. 9, 2026, 1:07 a.m.