databaseDiagnostics: Database diagnostics

View source: R/databaseDiagnostics.R

databaseDiagnosticsR Documentation

Database diagnostics

Description

phenotypeR diagnostics on the cdm object.

Diagnostics include: * Summarise a cdm_reference object, creating a snapshot with the metadata of the cdm_reference object. * Summarise the observation period table getting some overall statistics in a summarised_result object. * Summarise the person table including demographics (sex, race, ethnicity, year of birth) and related statistics.

Usage

databaseDiagnostics(cohort)

Arguments

cohort

Cohort table in a cdm reference

Value

A summarised result

Examples


library(omock)
library(PhenotypeR)
library(CohortConstructor)

cdm <- mockCdmFromDataset(source = "duckdb")

cdm$new_cohort <- conceptCohort(cdm,
                                conceptSet = list("codes" = c(40213201L, 4336464L)),
                                name = "new_cohort")



PhenotypeR documentation built on Feb. 9, 2026, 1:07 a.m.