View source: R/databaseDiagnostics.R
| databaseDiagnostics | R Documentation |
phenotypeR diagnostics on the cdm object.
Diagnostics include: * Summarise a cdm_reference object, creating a snapshot with the metadata of the cdm_reference object. * Summarise the observation period table getting some overall statistics in a summarised_result object. * Summarise the person table including demographics (sex, race, ethnicity, year of birth) and related statistics.
databaseDiagnostics(cohort)
cohort |
Cohort table in a cdm reference |
A summarised result
library(omock)
library(PhenotypeR)
library(CohortConstructor)
cdm <- mockCdmFromDataset(source = "duckdb")
cdm$new_cohort <- conceptCohort(cdm,
conceptSet = list("codes" = c(40213201L, 4336464L)),
name = "new_cohort")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.