- cohort
Cohort table in a cdm reference
- diagnostics
Vector indicating which diagnostics to perform. Options
include: `databaseDiagnostics`, `codelistDiagnostics`, `cohortDiagnostics`,
and `populationDiagnostics`.
- measurementSample
The number of people to take a random sample for
measurement diagnostics. If `measurementSample = NULL`, no sampling will be
performed. If `measurementSample = 0` measurement diagnostics will not be
run.
- drugExposureSample
The number of people to take a random sample for
drug diagnostics. If `drugExposureSample = NULL`, no sampling will be
performed. If `drugExposureSample = 0` drug diagnostics will not be
run.
- survival
TRUE or FALSE. Whether to conduct survival analysis (TRUE)
or not (FALSE).
- cohortSample
The number of people to take a random sample for cohortDiagnostics. If `cohortSample = NULL`, no sampling will be performed.
- matchedSample
The number of people to take a random sample for
matching. If `matchedSample = NULL`, no sampling will be performed. If `matchedSample = 0`, no
matched cohorts will be created.
- populationSample
Number of people from the cdm to sample. If NULL no
sampling will be performed. Sample will be within populationDateRange if
specified.
- populationDateRange
Two dates. The first indicating the earliest cohort
start date and the second indicating the latest possible cohort end date. If
NULL or the first date is set as missing, the earliest observation_start_date
in the observation_period table will be used for the former. If NULL or the
second date is set as missing, the latest observation_end_date in the
observation_period table will be used for the latter.